@@ -10,12 +10,13 @@ logger = logging.getLogger(__name__)
 
 
 class GPT3Generator:
-    # TODO: add parametrization around more flexible priming (instead of always using input-output)
     def __init__(self,
                  engine: str,
                  max_tokens: int,
                  temperature: float = 1,
-                 top_p: int = 1) -> None:
+                 top_p: int = 1,
+                 input_text: str = 'Input',
+                 output_text: str = 'Output') -> None:
         '''Wrapper for simplifying priming
         see https://beta.openai.com/docs/api-reference for documentation
         '''
@@ -23,6 +24,8 @@ class GPT3Generator:
         self.max_tokens = max_tokens
         self.temperature = temperature
         self.top_p = top_p
+        self.input_text = input_text
+        self.output_text = output_text
         self.instructions: str = ''
         self.examples: Dict[str, str] = {}
 
@@ -67,13 +70,13 @@ class GPT3Generator:
         if self.instructions == '' and not self.examples:
             raise ValueError('No prompt has been provided. Please use at least one of set_instructions(), add_examples().')
 
-        expanded_examples = '\n\n'.join([f'Input: {k}\nOutput: {v}' for k, v in self.examples.items()])
+        expanded_examples = '\n\n'.join([f'{self.input_text}: {k}\n{self.output_text}: {v}' for k, v in self.examples.items()])
         
         return f'{self.instructions}{expanded_examples}'
 
     def get_gpt3_response(self, starting_text: str) -> openai.openai_response:
         '''Call OpenAI API to get the prompt'''
-        prompt = self.get_prompt() + f'\n\nInput: {starting_text}'
+        prompt = self.get_prompt() + f'\n\n{self.input_text}: {starting_text}'
         try:
             return openai.Completion.create(engine=self.engine,
                                             prompt=prompt,
@@ -87,4 +90,4 @@ class GPT3Generator:
         '''Get generated text'''
         gpt3_response = self.get_gpt3_response(starting_text)
         generated_text = gpt3_response['choices'][0]['text'].strip()
-        return generated_text.split('\n\nInput')[0].replace('Output: ', '')
+        return generated_text.split('\n\n{self.input_text}')[0].replace('{self.output_text}: ', '')
